| aecdop | R Documentation |
Provides details on how votes are distributed and transferred among candidates in all count stages of the preferential voting system. All electoral divisions in the Australian Federal Election are included.
aecdop_2022
aecdop_2025
A tibble of 14 columns:
State or territory abbreviation (e.g., "ACT", "NSW", "VIC")
Numeric identifier for the electoral division
Name of the electoral division (e.g., "Bean", "Canberra")
Round in the counting procedure, starting from 0 (first preference)
Position of the candidate on the ballot paper
Unique numeric identifier for the candidate
Candidate's surname
Candidate's given name(s)
Party abbreviation (e.g., "UAPP", "ALP", "LP")
Full party name (e.g., "United Australia Party", "Australian Labor Party")
Whether the candidate was elected: "Y" (yes) or "N" (no)
Whether the candidate was elected in the previous election: "Y" (yes) or "N" (no)
Type of calculation:
Number of votes received
Percentage of votes received
Number of votes transferred from other candidates
Percentage of votes transferred from other candidates
Numeric value for the calculation type (votes or percentage)
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 35096 rows and 14 columns.
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 30888 rows and 14 columns.
Two datasets are provided:
aecdop_2022: 2022 Federal Election (35,096 rows)
aecdop_2025: 2025 Federal Election (30,888 rows)
Australian Electoral Commission (AEC) Distribution of Preferences 2022 Distribution of Preferences 2025
# Load the datasets
data(aecdop_2022)
data(aecdop_2025)
# First preferences for Bean division in 2022
aecdop_2022 |>
dplyr::filter(DivisionNm == "Bean",
CountNumber == 0,
CalculationType == "Preference Count")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.