| prefviz-package | R Documentation |
Visualises preference and ranking data by extending traditional ternary plots to support high-dimensional simplexes. The package provides methods to transform compositional data into coordinates suitable for 2D and high-dimensional ternary plots (see Cook & Laa (2024) https://dicook.github.io/mulgar_book/). Compatibility with interactive visualization packages such as 'plotly' or 'detourr' allows users to explore high-dimensional preference structures dynamically.
Maintainer: Linh Ngo Linh.Ngo2@monash.edu
Authors:
Dianne Cook DiCook@monash.edu (ORCID)
Damjan Vukcevic damjan.vukcevic@monash.edu (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.