| elb_centroid | R Documentation |
Provides the centroids of all electorates in the 2025 Australian Federal Election. The dataset is computed from 2025 Electoral Boundaries data.
elb_centroid
A tibble of 5 columns:
Unique identifier for electorate
Electoral division name
Area of the electorate in square kilometres
Longitude of the electoratecentroid
Latitude of the electorate centroid
Australian Electoral Commission (AEC) https://www.aec.gov.au/electorates/maps.htm
library(ggplot2)
library(ggthemes)
# Load the dataset
data(elb_centroid)
# Plot the centroids on top of the electoral boundaries
ggplot(elb_map) +
geom_polygon(
aes(x = long, y = lat, group = group),
fill = "grey90", color = "white") +
geom_point(
data = elb_centroid,
aes(x = long, y = lat),
size = 1, alpha = 0.8
) +
theme_map()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.