| ordered_path_df | R Documentation |
Internal helper to validate and reorder data
within each group according to the order_by aesthetic.
Used by stat_ordered_path().
ordered_path_df(
data,
group,
order_by,
decreasing = FALSE,
na_method = c("drop_na", "drop_group")
)
data |
A data frame containing at least an |
decreasing |
Logical. If |
na_method |
Character string indicating how to handle missing values in
|
A data frame with the same columns as data, but potentially fewer
rows (after dropping rows or groups) and with rows reordered within each
group.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.